pub struct FromColorMutGuard<'a, T, U>{ /* private fields */ }Expand description
A scope guard that restores the guarded colors to their original type when dropped.
Implementations
Sourceimpl<'a, T, U> FromColorMutGuard<'a, T, U>
impl<'a, T, U> FromColorMutGuard<'a, T, U>
Sourcepub fn then_into_color_mut<C>(self) -> FromColorMutGuard<'a, C, U>
pub fn then_into_color_mut<C>(self) -> FromColorMutGuard<'a, C, U>
Convert the colors to another type and replace this guard.
The colors will not be converted back to the current color type before
being restored, as opposed to when into_color_mut is called. Instead,
they are restored directly to their original type.
Sourcepub fn then_into_color_unclamped_mut<C>(
self,
) -> FromColorUnclampedMutGuard<'a, C, U>where
T: FromColorUnclampedMut<C>,
C: FromColorUnclampedMut<U> + FromColorUnclampedMut<T> + ?Sized,
U: FromColorUnclampedMut<C>,
pub fn then_into_color_unclamped_mut<C>(
self,
) -> FromColorUnclampedMutGuard<'a, C, U>where
T: FromColorUnclampedMut<C>,
C: FromColorUnclampedMut<U> + FromColorUnclampedMut<T> + ?Sized,
U: FromColorUnclampedMut<C>,
Convert the colors to another type, without clamping, and replace this guard.
The colors will not be converted back to the current color type before
being restored, as opposed to when into_color_unclamped_mut is called.
Instead, they are restored directly to their original type.
Sourcepub fn into_unclamped_guard(self) -> FromColorUnclampedMutGuard<'a, T, U>where
T: FromColorUnclampedMut<U>,
U: FromColorUnclampedMut<T>,
pub fn into_unclamped_guard(self) -> FromColorUnclampedMutGuard<'a, T, U>where
T: FromColorUnclampedMut<U>,
U: FromColorUnclampedMut<T>,
Replace this guard with a guard that does not clamp the colors after restoring.